summaryrefslogtreecommitdiffstats
path: root/kandy/src/mobilemain.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kandy/src/mobilemain.cpp')
-rw-r--r--kandy/src/mobilemain.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kandy/src/mobilemain.cpp b/kandy/src/mobilemain.cpp
index 851b7829..7b39d8d3 100644
--- a/kandy/src/mobilemain.cpp
+++ b/kandy/src/mobilemain.cpp
@@ -18,8 +18,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include <kglobal.h>
@@ -113,7 +113,7 @@ void MobileMain::dragEnterEvent(TQDragEnterEvent *event)
void MobileMain::dropEvent(TQDropEvent *event)
{
// this is a very simplistic implementation of a drop event. we
// will only accept a dropped URL. the Qt dnd code can do *much*
// much more, so please read the docs there
// do nothing
@@ -113,7 +113,7 @@ void MobileMain::dragEnterEvent(TQDragEnterEvent *event)
{
// this is a very simplistic implementation of a drop event. we
- // will only accept a dropped URL. the Qt dnd code can do *much*
+ // will only accept a dropped URL. the TQt dnd code can do *much*
// much more, so please read the docs there
// do nothing